function [so,bo] = wpar2(F, t, N, sig0, sigmax, bmax, Ntol)

%  The function [so,bo] = wpar2(F,t,N,sig0,sigmax,bmax,Ntol) estimates 
%  the optimal parameters s (= sigma) and b for the Weeks method.  
%  The function requires no information on the singularities of the transform.
%
%  Input:
%  F      -- Transform; symbolic function of s.
%  t      -- Ordinate where f(t) are to be computed (scalar).
%  N      -- Number of terms in the Weeks expansion.
%  sig0   -- Laplace convergence asbscissa.
%  sigmax -- Maximum possible value of sigma.
%  bmax   -- Maximum possible value of b.
%  Ntol   -- Determines the tolerance in the optimization routine fmin.
%            Large Ntol => small tolerance.  Recommended: Ntol = 20 to 50.
%  Output:
%  (so, bo) -- Estimated parameters to be used in weeks.m or weekse.m.

tols = (sigmax-sig0)/Ntol; 
tolb = bmax/Ntol;
options = optimset('fminbnd');
sooptnew = optimset(options,'TolX',tols);
booptnew = optimset(options,'TolX',tolb);
so = fminbnd('werr2e',sig0,sigmax,sooptnew,F,t,N,sig0,sigmax,bmax,tolb);
bo = fminbnd('werr2t',0,bmax,booptnew,F,N,so); 

