function [renewal] = isRenewal(trce)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Renewal test: test to see if the trace fits a renewal ON-OFF model
%%%% PREREQUISITE:
%%%%       (1) Test the trace for stationarity using stationaryCheck.m
%%%% INPUT:
%%%%       (1) The trace
%%%%       (2) The crosscorrThres: if there is significant correlation
%%%% OUTPUT: isRenewal =1 if the trace is renewal, 0 otherwise
%%%% COPYRIGHT : Hung X. Nguyen, the University of Adelaide, Australia
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%% Parameters used in the tests
crossCorrThres =0.7; %%% if the cross correlation is greater than this threshold
%%% the two timeseries are correlated


%%%% Variables used to stored the output
corrLNL=[];

lagLbl=[];
lagNLbl=[];

isRenewal=1;

%Getting the loss and no-loss series
[L NL]=LNL(trce);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%% Testing for independence in the loss runs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

laL=-100;
if (length(L)>10)
    
    %%% Testing for independence using the ACF test
    [c boundL]=autocorr(L);
    count =0;
    
    %%% Only look at the first half-corr coefficients,the rest sampling
    %%% errors are too high to be reliable 
    for i=2:length(c)/2
        if abs(c(i))>boundL
            count=count+1 ;
            %laL=i;
            %break
        end
    end
     
    %% Check 95% confidence intervals
    if count>0.05*length(c)/2 
        isRenewal=0;
    end
    
%     
%     %%% Testing for independence using the bl test
%     %[ACF,stderr,lpq,qpval,accept_hypotrce,laLbl] = bl(L,min(50,length(L)-2));
%     [h,pValue,stat,cValue] = lbqtest(L,min([20, length(L)-1]), 0.05);
%     
%     isRenewal=min(isRenewal,1-h);
    
else
    %Too small sample size
    isRenewal=0;
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%% Testing for independence of the good runs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

laNL=-100;
if (length(NL)>10)
    
    %%% Testing for independence using the ACF test
    [c boundNL]=autocorr(NL);
    count=0;
    for i=2:length(c)/2
        if abs(c(i))>boundNL
            count=count+1;
            %laNL=i;
            %break
        end
    end
    
    %%% Only look at the first half-corr coefficients,the rest sampling errors are too high to be reliable 
    if count>0.05*length(c)/2 
        isRenewal=0;
    end
    
%     %%% Testing for independence using the bl test
%     %%%[ACF,stderr,lpq,qpval,accept_hypotrce,laNLbl] = bl(NL,min(50,length(L)-2));
%     [h,pValue,stat,cValue] = lbqtest(NL, min([20, length(NL)-1]),0.05);
%     
%     isRenewal=min(isRenewal,1-h);
else
    %Too small sample size
    isRenewal=0;
end

%%%%%%% Correlation between good and loss run
if (length(NL)>10)
    tempCorr = corrcoef(L,NL);
    corrLNL=[corrLNL  tempCorr(1,2)];   
    
    if (tempCorr(1,2) >crossCorrThres)
        isRenewal=0;
    end
end
renewal=isRenewal;



