%%%%%%%%%
% Main program to generate the simulations
% 1. Generate the simulated trace using exponential ON and OFF duration
% 2. Call SAIL to get the parameters and the variance
% 3. Validate
% copyright: hung.nguyen@adelaide.edu.au
%%%%%%%%%

clear all

disp('Preparing the paths for function calls...');
addpath LIBRARY


ONP=1/5; %%%% 1/ average length of the Lossy period
OFFP =1/100; %%%1/average length of the Lossless period
lambda = 0.1;

%%%gamma dist parameters
ko=[5 1];
thetao=[1/(ko(1)*ONP)  1/(ko(2)*OFFP)];
noRep=1;


kArray=[];
thetaArray=[];
stationaryArray=[];
renewalArray=[];
LRINFER=[];
LREMP=[];
LRVAL=[];
VARINFER=[];
VAREMP=[];
VARVAL=[];
CONF=[];

lambdaArray=[0.1:0.1:1];
k1Array=[1:1:10];
k2Array=[1:1:10];

for lambdaID =5:1:5
    lambda=lambdaArray(lambdaID);
    %theta(2)=thetaidx;
    for k1ID=2:1:2
        ko(1)=k1Array(k1ID);
        for k2ID=5:1:5
            ko(2)=k2Array(k2ID);
            
            for rep=1:noRep
                
                thetao=[1/(ko(1)*ONP)  1/(ko(2)*OFFP)];
                n_samples=min(20000,floor(30*(1/OFFP +1/ONP)/lambda));
                
                %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                %%%%%% Simulate the input
                %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                disp(['Simulating the Alternating Renewal Gamma Process with parameters:',...
                    ' lambda=',num2str(lambda),' ,k(1)=',num2str(ko(1)),' ,k(2)=',...
                     num2str(ko(2)),' ,theta(1)=',num2str(thetao(1)),' ,theta(2)=',num2str(thetao(2))]);
                

                %%%%%% Gamma
                trce=-1*ones(n_samples,1);
                A_seq = cumsum(- log(rand(n_samples,1))/lambda); %% arrival time of samples;
                ON_seq= mygamrnd(ko(1),thetao(1),2*n_samples,0);
                OFF_seq= mygamrnd(ko(2),thetao(2),2*n_samples,0);
                
                R_seq=[0];
                
                idx=1;
                for i=1:2*n_samples
                    R_seq(idx+1) =R_seq(idx) + ON_seq(i);
                    R_seq(idx+2)= R_seq(idx+1) + OFF_seq(i);
                    idx=idx+2;
                end
                
                current_j=1;
                for i=1:n_samples
                    for j=current_j:length(R_seq)-1
                        if ((A_seq(i) > R_seq(j))&&(A_seq(i)<=R_seq(j+1)))
                            current_j=j;
                            break;
                        end
                    end
                    
                    if (mod(current_j,2) == 1)
                        trce(i)=0; %loss
                    else
                        trce(i)=1; %good
                    end
                    
                end
                
                %Checking for stationarity
                % SImulated traces should pass this test
                stationary=isStationary(trce);
                renewal=isRenewal(trce);
               
                
                %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                %%% Collecting statistics
                disp('Collecting statistics ...');
               
                stationaryArray=[stationaryArray stationary];
                renewalArray=[renewalArray renewal];
                
               
            end
        end
        
    end %rep
end %lambda
